package
Version:
v0.0.0-...-b952f1b
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Pool[T any] struct {
}
Pool 对象池
func (p *Pool[T]) Get() *T
func (p *Pool[T]) Put(obj *T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.